@@ -2,7 +2,7 @@
 #
 # The MIT License (MIT)
 #
-# Copyright (c) Tavendo GmbH
+# Copyright (c) Crossbar.io Technologies GmbH
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -36,7 +36,7 @@ version = __version__
 # see aio.py for asyncio/trollius implementation
 
 
-class _Config:
+class _Config(object):
     """
     This holds all valid configuration options, accessed as
     class-level variables. For example, if you were using asyncio:
@@ -58,6 +58,7 @@ class _Config:
 
 
 __all__ = (
+    'with_config',              # allow mutliple custom configurations at once
     'using_twisted',            # True if we're using Twisted
     'using_asyncio',            # True if we're using asyncio
     'use_twisted',              # sets the library to use Twisted, or exception
@@ -65,32 +66,37 @@ __all__ = (
 
     'config',                   # the config instance, access via attributes
 
-    'create_future',   # create a Future (can be already resolved/errored)
+    'create_future',            # create a Future (can be already resolved/errored)
     'create_future_success',
     'create_future_error',
-    'create_failure',  # return an object implementing IFailedFuture
-    'as_future',       # call a method, and always return a Future
-    'is_future',       # True for Deferreds in tx and Futures, @coroutines in asyncio
-    'reject',          # errback a Future
-    'resolve',         # callback a Future
-    'add_callbacks',   # add callback and/or errback
-    'gather',          # return a Future waiting for several other Futures
-    'is_called',       # True if the Future has a result
+    'create_failure',           # return an object implementing IFailedFuture
+    'as_future',                # call a method, and always return a Future
+    'is_future',                # True for Deferreds in tx and Futures, @coroutines in asyncio
+    'reject',                   # errback a Future
+    'resolve',                  # callback a Future
+    'cancel',                   # cancel a Future
+    'add_callbacks',            # add callback and/or errback
+    'gather',                   # return a Future waiting for several other Futures
+    'is_called',                # True if the Future has a result
 
-    'call_later',      # call the callback after the given delay seconds
+    'call_later',               # call the callback after the given delay seconds
 
-    'failure_message',    # a printable error-message from a IFailedFuture
-    'failure_traceback',  # returns a traceback instance from an IFailedFuture
-    'failure_format_traceback',  # a string, the formatted traceback
+    'failure_message',          # a printable error-message from a IFailedFuture
+    'failure_traceback',        # returns a traceback instance from an IFailedFuture
+    'failure_format_traceback',     # a string, the formatted traceback
 
-    'make_logger',     # creates an object implementing ILogger
-    'start_logging',   # initializes logging (may grab stdin at this point)
-    'set_global_log_level',  # Set the global log level
-    'get_global_log_level',  # Get the global log level
+    'make_batched_timer',       # create BatchedTimer/IBatchedTimer instances
+
+    'make_logger',              # creates an object implementing ILogger
+    'start_logging',            # initializes logging (may grab stdin at this point)
+    'set_global_log_level',     # Set the global log level
+    'get_global_log_level',     # Get the global log level
     'add_log_categories',
 
-    'IFailedFuture',             # describes API for arg to errback()s
-    'ILogger',                   # API for logging
+    'IFailedFuture',            # describes API for arg to errback()s
+    'ILogger',                  # API for logging
+
+    'sleep',                    # little helper for inline sleeping
 )
 
 
